@@ -53,14 +53,14 @@ if(plot_type==0):
         
         k_scaled = ks_scaled_path[i]
         k = ks_path[i]
-# =============================================================================
-#           harmonic things
+        
+        # harmonic things
         D = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
         eigvals = np.linalg.eigvalsh(D)
         idx = np.argsort(eigvals)
         eigvals = eigvals[idx]
         omegas = np.sqrt(eigvals)/2/np.pi
-# =============================================================================
+
         freq_disp = omegas
         print(' Creating plots for k point = ', k_scaled)
         for n in range(tot_atoms_uc*3):
@@ -134,14 +134,12 @@ if(plot_type==2):
                 accepted_qpoints.append(qpoint.tolist())
                 accepted_labels.append(labels[j])
                 
-# =============================================================================
-#               harmonic things
+                # harmonic things
                 D = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
                 eigvals = np.linalg.eigvalsh(D)
                 idx = np.argsort(eigvals)
                 eigvals = eigvals[idx]
                 omegas = np.sqrt(eigvals)/2/np.pi
-# =============================================================================
 
                 for m in range(Nqs_path):
                     if(np.allclose(qpoint,ks_scaled_path[m])):
@@ -209,11 +207,10 @@ if(plot_type==4):
     K_renorm = np.loadtxt('K_renorm')
     
     # take the path the user inputs and find all the k points you can plot
-    # ks_path, x_labels, distances_comm = read.read_path(kinput, Nqs_path, labels, Hk)
-    ks_scal_path_many, ks_path_many, distances = util.get_kpath_many(kinput, Hk, npoints=interp)
+    ks_scal_path_many, ks_path_many, distances = util.get_kpath_many(ks_scaled_path, Hk, npoints=interp+1)
     
     # SCell_fc, R0_fc, R_fc = util.get_R_FC(N1, N2, N3, 4,4,4,tot_atoms_uc, Suc, SCell) 
-
+# =============================================================================
     freq_DOS, DOS, DOS_renorm = np.arange(0,25,0.01), np.zeros(len(np.arange(0,25,0.01))), np.zeros(len(np.arange(0,25,0.01)))
     kpoints_scal, kpoints = util.get_kgrid(interp,interp,interp, Hk)
     N1N2N3_k = interp*interp*interp
@@ -222,22 +219,20 @@ if(plot_type==4):
         k = irr_ks[i]
         weight = weights[i]
         print('\t processing DOS k-point:', i, irr_ks_sc[i])
-# =============================================================================
-#           Renormalised          
+        # Renormalised          
         D = util.get_D(k, K_renorm,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
         eigvals_renorm, omegas_renorm = util.get_eigvals(D)
-# =============================================================================
-# =============================================================================
-#           0K dispersion
+        # 0K dispersion
         D_0K = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
         eigvals_0K, omegas_0K = util.get_eigvals(D_0K)
-# =============================================================================
+
         sigma = gaussian_smoothing
         DOS = DOS + np.sum(util.norm_gaussian(freq_DOS,omegas_0K,sigma), axis=1)*weight/(3*tot_atoms_uc*N1N2N3_k*2)
         DOS_renorm = DOS_renorm + np.sum(util.norm_gaussian(freq_DOS,omegas_renorm,sigma), axis=1)*weight/(3*tot_atoms_uc*N1N2N3_k*2)
     DOS_info = np.vstack((freq_DOS, DOS, DOS_renorm)).T
+# =============================================================================
     
-    
+# =============================================================================    
     count_k = 0
     frequencies = np.zeros((1,tot_atoms_uc*3,len(ks_path_many)))
     frequencies_disp = np.zeros((1,tot_atoms_uc*3,len(ks_path_many)))
@@ -258,15 +253,12 @@ if(plot_type==4):
             K_corr_0K, K_corr_renorm = K, K_renorm
         
         print('\t processing k-point:', i, ks_scal_path_many[i])
-# =============================================================================
-#           Renormalised          
+        # Renormalised          
         D_renorm = util.get_D(k, K_corr_renorm,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
         eigvals_renorm, eigvecs_renorm, omegas_renorm = util.get_eigvals_eigvec(D_renorm)
-# =============================================================================
-#           0K dispersion
+        # 0K dispersion
         D_0K = util.get_D(k, K_corr_0K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
         eigvals_0K, eigvecs_0K, omegas_0K = util.get_eigvals_eigvec(D_0K)
-# =============================================================================
         
         EIGVECS_0K.append(eigvecs_0K)
         EIGVECS.append(eigvecs_renorm)
@@ -274,6 +266,7 @@ if(plot_type==4):
         frequencies[:,:,count_k] = omegas_renorm 
         frequencies_disp[:,:,count_k] = omegas_0K 
         count_k = count_k + 1
+# =============================================================================
         
         
     # this is to reshape spectra according to real branches
@@ -291,13 +284,11 @@ if(plot_type==40):
     meta = len(freq)
     
     # take the path the user inputs and find all the k points you can plot
-    # ks_path, x_labels, distances_comm = read.read_path(kinput, Nqs_path, labels, Hk)
-    ks_scal_path_many, ks_path_many, distances = util.get_kpath_many(kinput, Hk, npoints=interp)
+    ks_scal_path_many, ks_path_many, distances = util.get_kpath_many(ks_scaled_path, Hk, npoints=interp+1)
     
     K_renorm = np.loadtxt('K_renorm')
     # SCell_fc, R0_fc, R_fc = util.get_R_FC(N1, N2, N3, 4,4,4,tot_atoms_uc, Suc, SCell) 
             
-    
 # =============================================================================
     freq_DOS, DOS = np.arange(0,25,0.01), np.zeros(len(np.arange(0,25,0.01)))
     kpoints_scal, kpoints = util.get_kgrid(interp, interp, interp, Hk)
@@ -405,7 +396,7 @@ if(plot_type==40):
 if(plot_type==5):
     print('Generating plot 5...')
     # take the path the user inputs and find all the k points you can plot, with interpolation
-    ks_scal_path_many, ks_path_many, distances_many = util.get_kpath_many(kinput, Hk, npoints=interp)
+    ks_scal_path_many, ks_path_many, distances_many = util.get_kpath_many(ks_scaled_path, Hk, npoints=interp+1)
     num_modes = len(modes)
     K_renorm = np.loadtxt('K_renorm')
 
@@ -487,24 +478,25 @@ if(plot_type==5):
     #this is to reshape spectra according to real branches
     indexes, freqs_reshaped = util.get_real_branches(frequencies, EIGVECS, masses_uc, ks_path_many)
     indexes_0K, freqs_disp_reshaped = util.get_real_branches(frequencies_disp, EIGVECS_0K, masses_uc, ks_path_many)
+    frequencies_reshaped, frequencies_disp_reshaped  = np.copy(frequencies), np.copy(frequencies_disp)
+    frequencies_reshaped, frequencies_disp_reshaped = freqs_reshaped, freqs_disp_reshaped
     
     ZQS_proj_reshaped = np.zeros((meta, num_modes, len(ks_path)))
     for j in range(len(ks_path)):
         ZQS_proj_reshaped[:,:,j] = ZQS_proj[:,indexes[j,modes],j]
     freqs_from_spectrum = util.freqs_spectrum(freq,ZQS_proj_reshaped)
     
-
     if (interp>0):
-        ZQS_proj = util.interpol_spectrum(ks_path, freq, freqs_from_spectrum, distances_comm, distances_many, frequencies, EIGVECS, modes, ZQS_proj_reshaped)
+        ZQS_proj_interp = util.interpol_spectrum(ks_path, freq, freqs_from_spectrum, distances_comm, distances_many, frequencies_reshaped[modes,:], EIGVECS, modes, ZQS_proj_reshaped)
     else:
-        ZQS_proj = ZQS_proj_reshaped[:,range(len(modes)),:]
+        ZQS_proj_interp = ZQS_proj_reshaped[:,range(len(modes)),:]
         
-    plot.plot_k2(distances_comm, distances_many, freqs_disp_reshaped, freqs_reshaped, freq,ZQS,ZQS_proj, x_labels,max_Z,modes)
+    plot.plot_k2(distances_comm, distances_many, frequencies_disp_reshaped, frequencies_reshaped, freq,ZQS,ZQS_proj_interp, x_labels,max_Z,modes)
 
 
 if(plot_type==6):
     num_modes = len(modes)
-    # ks_scal_path_many, ks_path_many, distances_many = util.get_kpath_many(kinput, Hk, npoints=interp)
+    # ks_scal_path_many, ks_path_many, distances_many = util.get_kpath_many(ks_scaled_path, Hk, npoints=interp+1)
     K_renorm = np.loadtxt('K_renorm')
     
     freq = np.loadtxt('ZS', usecols=0)
